<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['%d association'] = '%d Element wird insgesamt angezeigt (physisch und virtuell)';
$lang['%d associations'] = '%d Elemente werden insgesamt angezeigt (physisch und virtuell)';
$lang['%d album including'] = '%d Album inbegriffen, ';
$lang['%d albums including'] = '%d Alben inbegriffen, ';
$lang['%d physical'] = 'davon %d physisch';
$lang['%d physical'] = 'davon %d physische';
$lang[' and %d virtual'] = ' und %d virtuell';
$lang[' and %d virtual'] = ' und %d virtuelle';
$lang['%d album moved'] = '%d Album verschoben';
$lang['%d albums moved'] = '%d Alben verschoben';
$lang['%d group'] = '%d Gruppe';
$lang['%d groups'] = '%d Gruppe';
$lang['%d member'] = '%d Mitglied';
$lang['%d members'] = '%d Mitglieder';
$lang['%d tag'] = '%d Stichwort';
$lang['%d tags'] = '%d Stichworte';
$lang['%d user comment rejected'] = '%d Benutzerkommentar abgewiesen';
$lang['%d user comments rejected'] = '%d Benutzerkommentare abgewiesen';
$lang['%d user comment validated'] = '%d Benutzerkommentar freigeschaltet';
$lang['%d user comments validated'] = '%d Benutzerkommentare freigeschaltet';
$lang['%d user deleted'] = '%d Benutzer gelöscht';
$lang['%d users deleted'] = '%d Benutzer gelöscht';
$lang['%d user'] = '%d Benutzer';
$lang['%d users'] = '%d Benutzer';
$lang['%d waiting for validation'] = '%d warten auf Freischaltung';
$lang['Actions'] = 'Aktionen';
$lang['Activate'] = 'Aktiviere';
$lang['Add/delete a permalink'] = 'Hinzufügen/Löschen eines Permalinks';
$lang['Add a tag'] = 'Stichwort hinzufügen';
$lang['Add a user'] = 'Benutzer hinzufügen';
$lang['Add group'] = 'Gruppe hinzufügen';
$lang['Add'] = 'Hinzufügen';
$lang['Allow user registration'] = 'Erlaube die Neuregistrierung von Benutzern';
$lang['Apply to sub-albums'] = 'Einstellungen auch für Unteralben übernehmen';
$lang['Associated'] = 'ist verlinkt';
$lang['Batch management'] = 'Stapelverarbeitung';
$lang['Caddie management'] = 'Sammelkorb verwalten';
$lang['Caddie'] = 'Sammelkorb';
$lang['Albums authorized thanks to group associations'] = 'Für Alben freigeschaltet durch Gruppenzugehörigkeit';
$lang['Album manual order was saved'] = 'Albumreihenfolgen wurde gespeichert';
$lang['Check for upgrade failed for unknown reasons.'] = 'Suche nach einem Upgrade nicht möglich.';
$lang['Check for upgrade'] = 'Prüfe ob eine neue Version der Bildergalerie verfügbar ist.';
$lang['Comments for all'] = 'Kommentare für alle erlaubt';
$lang['Current name'] = 'Derzeitiger Name';
$lang['Database'] = 'Datenbank';
$lang['Deactivate'] = 'Deaktivieren';
$lang['Delete Representant'] = 'Lösche Vorschaubild';
$lang['Delete selected tags'] = 'Lösche markierte Stichworte';
$lang['Delete selected users'] = 'Lösche markierte Benutzer';
$lang['Deletions'] = 'Löschung';
$lang['Deny selected groups'] = 'Ausgewählte Gruppen ablehnen';
$lang['Deny selected users'] = 'Ausgewählte Benutzer ablehnen';
$lang['Description'] = 'Beschreibung';
$lang['Display options'] = 'Anzeigeeinstellungen';
$lang['Dissociated'] = 'ist nicht verlinkt';
$lang['Does not represent'] = 'Ist nicht Vorschaubild für dieses Album';
$lang['Edit selected tags'] = 'Bearbeite markierte Stichworte';
$lang['Edit tags'] = 'Bearbeite Stichworte';
$lang['Email admins when a new user registers'] = 'sende eine Email an den(die) Adminstrator(en) wenn sich ein neuer Benutzer registriert hat';
$lang['Email admins when a valid comment is entered'] = 'sende eine Email an den(die) Adminstrator(en) wenn ein Kommentar hinterlassen wurde';
$lang['Email admins when a comment requires validation'] = 'sende eine Email an den(die) Adminstrator(en) wenn ein Kommentar die Freischaltung durch den Admin erfordert';
$lang['Environment'] = 'Server-Daten';
$lang['Form'] = 'Formular';
$lang['Gallery title'] = 'Galerietitel';
$lang['Grant selected groups'] = 'Ausgewählte Gruppen zulassen';
$lang['Grant selected users'] = 'Ausgewählte Benutzer zulassen';
$lang['Group name'] = 'Gruppenname';
$lang['Groups'] = 'Gruppen';
$lang['Guests'] = 'Gäste';
$lang['History'] = 'Statistik';
$lang['Informations'] = 'Kategorieinformation';
$lang['Install'] = 'Installiere';
$lang['Link all album photos to a new album'] = 'Verbinde alle Album Elemente mit einem neuen Album';
$lang['Link all album photos to some existing albums'] = 'Verbinde alle Album Elemente mit einem existierenden Album';
$lang['Linked albums'] = 'Verlinktes Album';
$lang['Lock gallery'] = 'Blockiere den Zugriff auf die Datenbank';
$lang['Maintenance'] = 'Wartung';
$lang['Edit album permissions'] = 'Zugriffsrechte für ein privates Album verwalten';
$lang['Manage permissions for group "%s"'] = 'Verwalte die Zugriffsrechte auf private Alben für die Gruppe "%s"';
$lang['Manage permissions for user "%s"'] = 'Verwalte die Zugriffsrechte auf private Alben für den Benutzer "%s"';
$lang['Manage tags'] = 'Verwalte Stichworte';
$lang['Members'] = 'Mitglieder';
$lang['Metadata synchronized from file'] = 'Metadaten synchronisiert von Datei';
$lang['Move albums'] = 'Die Alben verschieben';
$lang['Move'] = 'Bewege';
$lang['Name'] = 'Name';
$lang['New name'] = 'Neuer Name';
$lang['New parent album'] = 'Neues übergeordnetes Album';
$lang['New tag'] = 'Neues Stichwort';
$lang['Number of comments per page'] = 'Anzahl von Kommentaren pro Seite';
$lang['Number of rates'] = 'Anzahl von Bewertungen';
$lang['Number of thumbnails to create'] = 'Anzahl von zu erstellenden Vorschaubildern';
$lang['Only private albums are listed'] = 'Nur als "privat" markierte Alben werden aufgelistet.';
$lang['Operating system'] = 'Betriebssystem';
$lang['Options'] = 'Optionen';
$lang['Other private albums'] = 'Weitere private Alben';
$lang['Page banner'] = 'Seitenbanner';
$lang['Parent album'] = 'Übergeordnetes Album';
$lang['Path'] = 'Pfad';
$lang['Permalink'] = 'Permalink';
$lang['Permalink %s has been previously used by album %s. Delete from the permalink history first'] = 'Permalink %s wurde vorher dem Album %s zugewiesen. Lösche ihn zuerst aus der History';
$lang['The permalink name must be composed of a-z, A-Z, 0-9, "-", "_" or "/". It must not be numeric or start with number followed by "-"'] = 'Ein Permalink darf nur aus folgenden Zeichen bestehen: a-z, A-Z, 0-9, "-" or "_". Er darf nicht nur aus Zahlen bestehen oder mit einer Zahl beginnen mit einem darauffolgenden "-"';
$lang['Permalink %s is already used by album %s'] = 'Permalink %s wird zurzeit vom Album %s benutzt';
$lang['Permalink history'] = 'Permalink-Historie';
$lang['Permalinks'] = 'Permalinks';
$lang['Permission denied'] = 'Zugriff verweigert';
$lang['Permission granted thanks to a group'] = 'Benutzern durch Zugehörigkeit in einer Gruppe ist der Zugriff erlaubt';
$lang['Permission granted'] = 'Zugriff erlaubt';
$lang['Photo informations updated'] = 'Fotoinformationen aktualisiert';
$lang['Plugins'] = 'Plugins';
$lang['Position'] = 'Position';
$lang['Preferences'] = 'Einstellungen';
$lang['Properties'] = 'Eigenschaften';
$lang['Random photo'] = 'Zufälliges Foto';
$lang['Rate date'] = 'Bewertungsdatum';
$lang['Rating by guests'] = 'Erlaube Bewertung(en) durch Gäste';
$lang['Rating'] = 'Bewertungen';
$lang['Reject'] = 'abweisen';
$lang['Representant'] = 'Vorschaubild';
$lang['Representation of albums'] = 'Galerievorschaubild';
$lang['Representative'] = 'Vorschaubild';
$lang['Represents'] = 'Ist Vorschaubild für diese Kategorien';
$lang['Save order'] = 'Reihenfolge speichern';
$lang['Save to permalink history'] = 'Speichere in der Permalink-Historie';
$lang['Select at least one album'] = 'Mindestens ein Album auswählen';
$lang['Select at least one photo'] = 'Wähle mindestens ein Fhoto';
$lang['Select at least one user'] = 'Mindestens einen Benutzer auswählen';
$lang['Show info'] = 'Info anzeigen';
$lang['Site manager'] = 'Seitenmanager';
$lang['Status'] = 'Status';
$lang['Statistics'] = 'Statistik';
$lang['Storage album'] = 'Speicherort des Albums';
$lang['Sum of rates'] = 'Summe der Bewertungen';
$lang['Tag "%s" already exists'] = 'Stichwort "%s" existiert bereits';
$lang['Tag "%s" was added'] = 'Stichwort "%s" wurde hinzugefügt';
$lang['Tag selection'] = 'Stichwortauswahl';
$lang['The %d following tags were deleted'] = 'Die %d folgenden Stichworte werden gelöscht :';
$lang['Unable to check for upgrade.'] = 'Update-Prüfung ist nicht möglich.';
$lang['Uninstall'] = 'Deinstallieren';
$lang['Use the default photo sort order (defined in the configuration file)'] = 'Nutze die Standard-Sortierreihenfolge (Definiert in der Konfigurationsdatei)';
$lang['User comments validation'] = 'Kommentare warten auf Freigabe';
$lang['Users'] = 'Benutzer';
$lang['Validate'] = 'Freigeben';
$lang['Validation'] = 'Freigabe der Kommentare durch den Administrator';
$lang['Version'] = 'Version';
$lang['Virtual albums to move'] = 'Wähle einen oder mehrere Virtuelle Alben aus um sie zu verschieben';
$lang['Virtual album name'] = 'Virtueller Albumname';
$lang['Webmaster cannot be deleted'] = 'Webmaster kann nicht gelöscht werden';
$lang['You are running on development sources, no check possible.'] = 'Sie benutzen eine Entwicklerversion von Piwigo, es kann keine Suche nach Aktualisierungen vorgenommen werden.';
$lang['You cannot delete your account'] = "Du kannst deinen eigenen Acount nicht löschen";
$lang['You cannot move an album in its own sub album'] = 'Sie können ein Album nicht in seinem eigenen Sub-Album verschieben.';
$lang['You need to confirm deletion'] = 'Löschen bitte bestätigen';
$lang['add tags'] = 'Stichworte hinzufügen';
$lang['Associate to album'] = 'Mit einem Album verbinden';
$lang['associate to group'] = 'Mit Gruppe verbinden';
$lang['Authorized'] = 'Zugriff erlaubt';
$lang['Add a virtual album'] = 'Virtuelles Album hinzufügen';
$lang['Authorize users to add comments on selected albums'] = 'Benutzern erlauben, in ausgewählten Alben Kommentare zu schreiben';
$lang['The name of an album must not be empty'] = 'Der Name eines Albums darf nicht leer sein.';
$lang['Lock albums'] = 'Alben sperren';
$lang['Private'] = 'Privat';
$lang['Public'] = 'Öffentlich';
$lang['Find a new representant by random'] = 'Bestimme ein neues zufälliges Vorschaubild';
$lang['Public / Private'] = 'Öffentlich / Privat';
$lang['Manage authorizations for selected albums'] = 'Zugriffsrechte durch private Alben verwalten';
$lang['Virtual album added'] = 'Virtuelles Album hinzugefügt';
$lang['Virtual album deleted'] = 'Virtuelles Album entfernt';
$lang['Access type'] = 'Zugangsart';
$lang['Comments'] = 'Benutzerkommentare';
$lang['Information data registered in database'] = 'Änderungen wurden gespeichert';
$lang['Default display'] = 'Standarddarstellung';
$lang['The gallery URL is not valid.'] = 'Die URL der Galerie ist falsch.';
$lang['Main'] = 'Grundeinstellungen';
$lang['The number of comments a page must be between 5 and 50 included.'] = 'Anzahl der Kommentare pro Seite muss zwischen 5 und 50 liegen.';
$lang['Configuration'] = 'Konfiguration';
$lang['confirm'] = 'bestätigen';
$lang['Date'] = 'Datum';
$lang['delete album'] = 'Album löschen';
$lang['Dissociate from album'] = 'Von Album abtrennen';
$lang['dissociate from group'] = 'Von Gruppe abtrennen';
$lang['edit album permissions'] = 'Zugriffsrechte auf das Album bearbeiten';
$lang['Album updated successfully'] = 'Informationen des Albums wurden erfolgreich aktualisiert.';
$lang['photos per page'] = 'Fotos je Seite';
$lang['High definition enabled'] = 'High definition eingeschaltet';
$lang['File'] = 'Datei';
$lang['Filesize'] = 'Dateigröße';
$lang['first photo added on %s'] = 'erstes Foto am %s hinzugefügt';
$lang['Forbidden'] = 'Zugriff verweigert';
$lang['global mode'] = 'Globaler Modus';
$lang['group "%s" added'] = 'Gruppe "%s" hinzugefügt';
$lang['group "%s" deleted'] = 'Gruppe "%s" gelöscht';
$lang['group "%s" updated'] = 'Gruppe "%s" aktualisiert';
$lang['group'] = 'Gruppe';
$lang['The name of a group must not contain " or \' or be empty.'] = 'Der Gruppenname darf kein " oder \' enthalten oder leer bleiben.';
$lang['This name is already used by another group.'] = 'Diesen Gruppenname gibt es schon.';
$lang['High definition'] = 'High definition';
$lang['jump to album'] = 'gehe zum Album';
$lang['jump to photo'] = 'springe zu Foto';
$lang['leave'] = 'Beibehalten';
$lang['Lock'] = 'Sperren';
$lang['Locked'] = 'Gesperrt';
$lang['manage album photos'] = 'verwalte Fotos im Album';
$lang['manage sub-albums'] = 'Verwalten Sie die Sub-Alben';
$lang['Manage'] = 'Verwalten';
$lang['maximum height'] = 'maximale Höhe';
$lang['maximum width'] = 'maximale Breite';
$lang['Execution time is out, treatment must be continue [Estimated time: %d second].'] = 'Ausführungszeit ist beendet, Vorgang muss manuell fortgesetzt werden [Verstrichene Zeit: %d Sekunde].';
$lang['Prepared time for list of users to send mail is limited. Others users are not listed.'] = 'Die vorgesehene Zeit zum versenden von E-Mail ist begrenzt. Andere Benutzer werden nicht aufgelistet.';
$lang['Time to send mail is limited. Others mails are skipped.'] = 'Die Zeit zum E-Mail versenden ist begrenzt. Nicht abgearbeitete Mails werden übersprungen';
$lang['To send ?'] = 'Info-Mail senden?';
$lang['Last send'] = 'Letzter Versand';
$lang['email'] = 'E-mail';
$lang['User'] = 'Benutzer';
$lang['Complementary mail content'] = 'Detaillierter Inhalt der Benachrichtigungsmail';
$lang['See you soon,'] = 'Bis bald,';
$lang['Go to'] = 'Gehe zu ';
$lang['Hello'] = 'Hallo ';
$lang['New photos were added'] = 'Neue Fotos wurden hinzugefügt';
$lang['on'] = ' am ';
$lang['between'] = 'zwischen dem';
$lang['and'] = ' und dem ';
$lang['The webmaster has subscribed you to receiving notifications by mail.'] = 'Der Webmaster hat dich für die E-Mailbenachrichtigung eingetragen. Das bedeutet nicht, das du "zugemüllt" wirst, sondern gelegentlich eine E-Mail über aktualisierte Bilder/Kategorien in der Bildergalerie. Die E-Mail wird nicht vom System, sondern vom Webmaster selbst ausgelöst. Falls du das als Belästigung empfindest, klicke unten einfach auf den Link "Austragen".';
$lang['You have subscribed to receiving notifications by mail.'] = 'Sie sind eingetragen für die Benachrichtigung per E-Mail';
$lang['To subscribe'] = 'Zum wieder anmelden';
$lang['If you encounter problems or have any question, please send a message to'] = 'Bei Problemen oder Fragen sende eine E-Mail an ';
$lang['[NBM] Problems or questions'] = '[NBM] Probleme oder Fragen';
$lang['The webmaster has unsubscribed you from receiving notifications by mail.'] = 'Der Webmaster hat dich für die E-Mailbenachrichtigung ausgetragen';
$lang['You have unsubscribed from receiving notifications by mail.'] = 'Sie haben sich ausgetragen für die Benachrichtigung per E-Mail';
$lang[', click on'] = ', klicke auf diesen Link:';
$lang['To unsubscribe'] = 'Zum austragen';
$lang['With blank value, gallery title will be used'] = 'Bei leerem Inhalt wird der Galerietitel benutzt';
$lang['Notification'] = 'Benachrichtigung';
$lang['Error when sending email to %s [%s].'] = 'Fehler beim Versand an %s [%s].';
$lang['Mail sent to %s [%s].'] = 'E-Mail versendet an %s [%s].';
$lang['%d mail was sent.'] = '%d E-Mail wurde gesendet.';
$lang['%d mails were sent.'] = '%d E-Mails wurden gesendet.';
$lang['%d mail was not sent.'] = '%d E-Mail wurde nicht gesendet.';
$lang['%d mails were not sent.'] = '%d E-Mails wurden nicht gesendet.';
$lang['No mail to send.'] = 'Keine E-Mail zu versenden.';
$lang['There is no available subscribers to mail.'] = 'Kein Benutzer verfügbar um eine E-Mail zu senden.';
$lang['Subscribers could be listed (available) only if there is new elements to notify.'] = 'Ein Benutzer ist dann auswählbar wenn es neue Fotos gibt.';
$lang['Anyway only webmasters can see this tab and never administrators.'] = 'Wenn niemand in der Mailingliste eingetragen ist, kannst du keine E-Mails versenden. (Nur der Webmaster erscheint bei Aktualisierungen in dieser Liste).';
$lang['No user to send notifications by mail.'] = 'Kein Benutzer da um Aktualisierungen zu senden.';
$lang['New photos added'] = 'Neue Fotos hinzugefügt';
$lang['Subscribe to notification by mail'] = 'Eintragen zur E-Mailbenachrichtigung';
$lang['Unsubscribe from notification by mail'] = 'Austragen zur E-Mailbenachrichtigung';
$lang['Parameter'] = 'Parameter';
$lang['Continue processing treatment'] = 'Prozess fortsetzen';
$lang['Complementary mail content'] = 'Zusätzlicher Inhalt der E-Mail';
$lang['Add detailed content'] = 'Sende detallierten Inhalt';
$lang['Send mail as'] = 'Sende E-Mail als';
$lang['Send mail to users'] = 'Sende Mail an';
$lang['Send'] = 'Sende';
$lang['Options'] = 'Optionen';
$lang['Subscribed'] = 'Bestätigt';
$lang['Subscribe'] = 'Bestätigen';
$lang['Parameters'] = 'Parameter';
$lang['Select recipients'] = 'Wähle Empfänger';
$lang['Subscribe/unsubscribe users'] = 'Hinzufügen/Entfernen von Benutzern für die E-Mailbenachrichtigung';
$lang['Unsubscribed'] = 'Entfernt';
$lang['%d parameter was updated.'] = '%d Parameter aktualisiert.';
$lang['%d parameters were updated.'] = '%d Parameter aktualisiert.';
$lang['%d user was not updated.'] = '%d Benutzer nicht aktualisiert.';
$lang['%d users were not updated.'] = '%d Benutzer nicht aktualisiert.';
$lang['User %s [%s] was removed from the subscription list.'] = 'Benutzer %s [%s] entfernt von der Benachrichtigungsliste.';
$lang['User %s [%s] was added to the subscription list.'] = 'Benutzer %s [%s] hinzugefügt zur Benachrichtigungsliste.';
$lang['%d user was updated.'] = '%d Benutzer aktualisiert.';
$lang['%d users were updated.'] = '%d Benutzer aktualisiert.';;
$lang['User %s [%s] was not removed from the subscription list.'] = 'Benutzer %s [%s] nicht entfernt von der Benachrichtigungsliste.';
$lang['User %s [%s] was not added to the subscription list.'] = 'Benutzer %s [%s] nicht hinzugefügt zur Benachrichtigungsliste.';
$lang['User %s [%s] added.'] = 'Benutzer %s [%s] hinzugefügt.';
$lang['Warning: subscribing or unsubscribing will send mails to users'] = 'WARNUNG: Hinzufügen oder Entfernen von Benutzern zur Mailingliste erwirkt sofort eine automatische E-Mail an den Betreffenden';
$lang['Send mail on HTML format'] = 'Sende E-Mail im HTML-Format';
$lang['Include display of recent photos grouped by dates'] = 'Binde die neuesten Bilder, gruppiert nach Datum, in die Email ein';
$lang['Available only with HTML format'] = 'Nur verfügbar, wenn die Benachrichtigungen im HTML-Format verschickt werden';
$lang['no write access'] = 'kein Schreibzugriff';
$lang['Permissions'] = 'Zugriffsrechte';
$lang['private'] = 'private';
$lang['public'] = 'öffentlich';
$lang['Purge never used notification feeds'] = 'Lösche alle noch nicht verschickten Benachrichtigungen';
$lang['Purge sessions'] = 'Lösche Sitzungen';
$lang['randomly represented'] = 'zufälliges Vorschaubild';
$lang['registration date'] = 'Registrierungsdatum';
$lang['clean'] = 'reinigen';
$lang['remove remote listing.xml file'] = 'Löschen Sie die Datei listing.xml Remote';
$lang['generate listing'] = 'generieren listing';
$lang['generate file listing.xml on remote site'] = 'listing.xml-Datei generiert auf dem Remote-Standort';
$lang['Create this site'] = 'Erstellen dieser Website';
$lang['A local listing.xml file has been found for'] = 'Listing.xml lokalen Datei gefunden wurde für ';
$lang['read local listing.xml and update'] = 'lesen listing.xml lokalen und zu aktualisieren';
$lang['test'] = 'Test';
$lang['test this remote site'] = 'testen Remote-Site';
$lang['remove tags'] = 'Stichworte entfernen';
$lang['Repair and optimize database'] = 'Reparieren und Optimierung der Datenbank';
$lang['selection'] = 'Auswahl';
$lang['set to'] = 'Setze auf';
$lang['singly represented'] = 'festgelegtes Vorschaubild';
$lang['This site already exists'] = 'Diese Seite gibt es bereits';
$lang['Create a new site : (give its URL to create_listing_file.php)'] = 'Erstellen Sie eine neue Remote-Seite: (genaue URL zur create_listing_file.php der Remote-Seite)';
$lang['created'] = 'erstellt';
$lang['delete this site and all its attached elements'] = 'Entfernen dieser Seite und alle damit zusammenhängenden Daten';
$lang['an error happened'] = 'ein Fehler ist aufgetreten';
$lang['file create_listing_file.php on remote site was not found'] = 'Die Datei create_listing_file.php wurde nicht gefunden auf der Remote-Seite';
$lang['Local'] = 'Lokal';
$lang['Remote'] = 'Remote';
$lang['synchronize'] = 'synchronisieren';
$lang['update the database from files'] = 'aktualisiert die Datenbank aus den Dateien';
$lang['status'] = 'Status';
$lang['Directory'] = 'Verzeichnis';
$lang['sub-albums'] = 'Sub-Album';
$lang['synchronize metadata'] = 'Synchronisieren von Meta-Daten';
$lang['target'] = 'Ziel:';
$lang['Thumbnail'] = 'Vorschaubild';
$lang['title'] = 'Titel';
$lang['Album list management'] = 'Albumverwaltung';
$lang['Piwigo configuration'] = 'Konfiguration der Piwigo';
$lang['Edit album'] = 'Einen Album bearbeiten';
$lang['Group management'] = 'Gruppenliste und -verwaltung';
$lang['User list'] = 'Benutzerliste und -verwaltung';
$lang['Edit photo information'] = 'Bearbeite Fotoinformation';
$lang['Thumbnail creation'] = 'Erstellung von Vorschaubildern';
$lang['Database synchronization with files'] = 'Synchronisierung der Datenbank';
$lang['all'] = 'alle';
$lang['photos without thumbnail (jpeg and png only)'] = 'Fotos ohne Vorschaubild (nur jpeg und png)';
$lang['height must be a number superior to'] = 'die Höhe muss größer sein als';
$lang['width must be a number superior to'] = 'die Breite muss größer sein als';
$lang['for the file format'] = 'für das Format der Datei';
$lang['No missing thumbnail'] = 'Kein Vorschaubild fehlt';
$lang['Photo unreachable or no support'] = 'Foto unerreichbar oder nicht unterstützt';
$lang['GD version'] = 'Version von GD Library';
$lang['Miniaturization parameters'] = 'Einstellungen für die Vorschaubilderstellung';
$lang['generated in'] = 'generiert in';
$lang['Results of miniaturization'] = 'Ergebnis der Vorschaubilderstellung';
$lang['General statistics'] = 'Allgemeine Statistiken';
$lang['max time'] = 'max Zeit';
$lang['average time'] = 'durchschnittliche Zeit';
$lang['min time'] = 'min Zeit';
$lang['number of miniaturized photos'] = 'Anzahl verkleinerter Fotos';
$lang['total time'] = 'Gesamtzeit';
$lang['for this file format'] = 'für dieses Dateiformat';
$lang['unit mode'] = 'Einzelmodus';
$lang['Unlocked'] = 'Entsperrt';
$lang['unset'] = 'Lösche Einstellung';
$lang['Update albums informations'] = 'Informationen der Alben aktualisieren';
$lang['Update photos information'] = 'Aktualisiere Fotoinformation';
$lang['Synchronize'] = 'Synchronisieren';
$lang['reduce to single existing albums'] = 'Auf einzelne bestehende Alben reduzieren';
$lang['Choose an option'] = 'Eine Option auswählen';
$lang['display maximum informations (added albums and photos, deleted albums and photos)'] = 'zeige alle Informationen (hinzugefügte Alben und Fotos, gelöschte Alben und Fotos)';
$lang['Piwigo version differs on the remote site'] = 'PhpWebGallery version unterscheidet sich von der Remote-Seite';
$lang['Version of create_listing_file.php on the remote site and Piwigo must be the same'] = 'Die Version von create_listing_file.php auf der Remote-Seite und PhpWebGallery muss die gleiche sein';
$lang['listing.xml file was not found'] = 'listing.xml Datei nicht gefunden';
$lang['listing.xml file was not found on the remote site. This file is generated by choosing the "generate listing" command in the Site manager'] = 'listing.xml Datei nicht gefunden auf der Remote-Seite. This file is generated by choosing the "generate listing" command in the Site manager';
$lang['Error list'] = 'Error Liste';
$lang['Errors caption'] = 'Fehlerüberschrift';
$lang['Detailed informations'] = 'Detallierte Informationen';
$lang['File/directory read error'] = 'Datei/Ordner Lesefehler';
$lang['The file or directory cannot be accessed (either it does not exist or the access is denied)'] = 'Auf diese Datei/Ordner kann nicht zugegriffen werden (Entweder es existiert nicht oder der Zugriff wurde verwehrt)';
$lang['a picture filetype requires a thumbnail. The thumbnail must be present in the sub-directory "thumbnail" of the album directory. The thumbnail filename must start with the configured thumbnail prefix and the extension must be among the following list :'] = 'Ein Bild braucht ein Vorschaubild. Das Vorschaubild muß sich im Unterverzeichnis "thumbnail" des Kategorieverzechnisses befinden. Der Dateiname des Vorschaubildes muß mit dem eingestellten Thumbnail-Vorzeichen beginnen und der Dateityp einem der folgenden entsprechen :';
$lang['missing thumbnail'] = 'Fehlendes Vorschaubild';
$lang['albums deleted in the database'] = 'Alben von der Datenbank entfernt';
$lang['photos deleted from the database'] = 'von der Datenbank gelöschte Fotos';
$lang['photos candidates for metadata synchronization'] = 'Fotos zur Metadata Synchronisation';
$lang['photos informations synchronized with files metadata'] = 'Fotoinformationen mit den Metadaten der Datei synchronisiert';
$lang['errors during synchronization'] = 'Fehler während der Synchronisation';
$lang['albums added in the database'] = 'Alben in der Datenbank hinzugefügt';
$lang['photos added in the database'] = 'der Datenbank hinzugefügte Fotos';
$lang['photos updated in the database'] = 'in der Datenbank aktualisierte Fotos';
$lang['Search for new images in the directories'] = 'Suche nach neuen Fotos in den vorhandenen Ordnern';
$lang['added'] = 'hinzugefügt';
$lang['deleted'] = 'gelöscht';
$lang['Metadata synchronization results'] = 'Metadata Synchronisierung Ergebnisse';
$lang['only perform a simulation (no change in database will be made)'] = 'nur Simulation (es werden keine Änderungen in der Datenbank vorgenommen)';
$lang['[Simulation]'] = '[Simulation]';
$lang['Simulation'] = 'Simulation';
$lang['directories + files'] = 'Ordner und Dateien';
$lang['only directories'] = 'Nur Ordner';
$lang['synchronize files structure with database'] = 'Syncronisiere Dateistruktur mit der Datenbank';
$lang['synchronize files metadata with database photos informations'] = 'synchronisiere Metadaten der Datei mit den Fotoinformationen der Datenbank';
$lang['even already synchronized photos'] = 'auch bereits synchronisierte Fotos';
$lang['Used metadata'] = 'Benutzte Metadaten';
$lang['The name of directories and files must be composed of letters, numbers, "-", "_" or "."'] = 'Der Verzeichnis- und der Dateiname muß aus Buchstaben oder den Zeichen "-", "_" oder "." bestehen';
$lang['wrong filename'] = 'Falscher Dateiname';
$lang['Upload'] = 'Upload';
$lang['user "%s" added'] = 'Benutzer "%s" hinzugefügt';
$lang['User status'] = 'Status des Benutzers';
$lang['user_status_admin'] = 'Administrator';
$lang['user_status_generic'] = 'Generischer Status';
$lang['user_status_guest'] = 'Gast';
$lang['user_status_normal'] = 'Benutzer';
$lang['user_status_webmaster'] = 'Webmaster';
$lang['Virtual album'] = 'Virteller Album';
$lang['Waiting'] = 'Wartend auf Freigabe';
$lang['default'] = 'Standard';
$lang['Toggle \'default group\' property'] = 'Setzt die Gruppe als Standardgruppe. (Neu registrierte Benutzer gehören automatisch dieser Gruppe an!)';
$lang['Advanced features'] = 'Erweiterte Einstellungen';
$lang['Specials'] = 'Erweiterte Auswahl';
$lang['Overall'] = 'Gesamt';
$lang['Year'] = 'Jahr';
$lang['Month'] = 'Monat';
$lang['Day'] = 'Tag';
$lang['Pages seen'] = 'Seitenzugriffe';
$lang['Time'] = 'Zeit';
$lang['IP'] = 'IP';
$lang['Element'] = 'Bilder';
$lang['Section'] = 'Abschnitt';
$lang['Tags'] = 'Stichworte';
$lang['Save page visits by guests'] = 'Speichere Seitenaufrufe von Gästen';
$lang['Save page visits by users'] = 'Speichere Seitenaufrufe pro Benutzer';
$lang['Save page visits by administrators'] = 'Speichere auch Seitenaufrufe des Administrators';
$lang['An information email was sent to group "%s"'] = 'Eine Info-E-Mail wurde gesendet an die Gruppe "%s"';
$lang['Send an information email to group members'] = 'Sende eine Info-E-Mail an die Mitglieder dieser Gruppe';
$lang['Group'] = 'Gruppe';
$lang['[%s] Visit album %s'] = '[%s] Besuchen sie den Album %s';
$lang['Hello,'] = 'Hallo,';
$lang['See you soon.'] = 'Bis bald.';
$lang['Discover album:'] = 'Folgen Sie den Link und entdecken Sie den Album:';
$lang['Mail content'] = 'Text der E-Mail';
$lang['none'] = 'egal';
$lang['high'] = 'hoch';
$lang['other'] = 'anderes';
$lang['Element type'] = 'Element Typ';
$lang['Image id'] = 'Element-ID';
$lang['Summary'] = 'Zusammenfassung';
$lang['%d line filtered'] = '%d Zeile gefiltert';
$lang['%d lines filtered'] = '%d Zeilen gefiltert';
$lang['%d guest'] = '%d Gast';
$lang['%d guests'] = '%d Gäste';
$lang['Hour'] = 'Stunde';
$lang['guest'] = 'Gast';
$lang['default values'] = 'Standardwerte';
$lang['High filesize'] = 'HQ Dateigröße';
// --------- Starting below: New or revised $lang ---- from version 1.7.1
$lang['Guest cannot be deleted'] = 'Der Gast kann nicht gelöscht werden';
$lang['Default user cannot be deleted'] = 'Der Standardbenutzer kann nicht gelöscht werden';
$lang['Purge history detail'] = 'Lösche History detailliert';
$lang['Purge history summary'] = 'Lösche History gesamt';
$lang['Check integrity'] = 'überprüfung der Integrität';
$lang['Anomaly'] = 'Anomalie';
$lang['Correction'] = 'Korrektur';
$lang['Automatic correction'] = 'Automatische Korrektur';
$lang['Impossible automatic correction'] = 'Automatische Korrektur nicht möglich';
$lang['Correction applied with success'] = 'Korrektur erfolgreich';
$lang['Correction applied with error'] = 'Korrektur mit Fehler';
$lang['%d anomaly has been detected.'] = '%d Anomalie entdeckt wurde.';
$lang['%d anomalies have been detected.'] = '%d Anomalien festgestellt wurden.';
$lang['%d anomaly has been corrected.'] = '%d Anomalie wurde behoben.';
$lang['%d anomalies have been detected corrected.'] = '%d Anomalien wurde behoben.';
$lang['%d anomaly has not been corrected.'] = '%d Anomalie konnte nicht behoben werden.';
$lang['%d anomalies have not been corrected.'] = '%d Anomalien konnte nicht behoben werden.';
$lang['Go to %s or %s for more informations'] = 'Gehen Sie %s oder %s für weitere Informationen';
$lang['the forum'] = 'das Forum';
$lang['the wiki'] = 'das wiki';
$lang['%s value is not correct file because exif are not supported'] = 'Der Wert %s ist nicht korrekt weil EXIF nicht unterstützt wird';
$lang['%s must be to set to false in your local/config/config.inc.php file'] = '%s muss auf "false" in Ihrer Datei config_local.inc.php';
$lang['Main "guest" user does not exist'] = 'Der Benutzer "Gast" Haupt nicht mehr';
$lang['Main "guest" user status is incorrect'] = 'Der Status der Benutzer "Gast" ist falsch';
$lang['Default user does not exist'] = 'Der Benutzer standardmäßig nicht mehr';
$lang['Main "webmaster" user does not exist'] = 'Der Benutzer "Webmaster" Haupt nicht mehr';
$lang['Main "webmaster" user status is incorrect'] = 'Der Status des Benutzers "Webmaster" ist falsch';
$lang['User "%s" created with "%s" like password'] = 'Benutzer "%s" erstellt mit dem Passwort "%s"';
$lang['Status of user "%s" updated'] = 'Status des Benutzers "%s" aktualisiert';
$lang['add new photos to caddie'] = 'füge neue Fotos zum Sammelordner hinzu';
// --------- Starting below: New or revised $lang ---- from Butterfly
$lang['No display'] = 'Keine Anzeige';
$lang['Classic display'] = 'Klassische Ansicht';
$lang['Hoverbox display'] = 'Anzeige beim überflug';
$lang['Mail address is obligatory for all users'] = 'Die Angabe einer gültigen E-Mail-Adresse ist für alle Benutzer verpflichtend';
$lang['Minimum privacy level'] = 'Minimale Datenschutzstufe';
$lang['Privacy level'] = 'Datenschutzstufe';
$lang['Level 0'] = '---';
$lang['Level 1'] = 'Kontakt';
$lang['Level 2'] = 'Freunde';
$lang['Level 4'] = 'Familie';
$lang['Level 8'] = 'Administratoren';
$lang['Reinitialize check integrity'] = 'prüfe erneut die Integrität';
$lang['Check all'] = 'Alle auswählen';
$lang['Uncheck all'] = 'Alles entfernen';
$lang['Check automatic corrections'] = 'überprüfen Sie automatische Korrekturen';
$lang['Apply selected corrections'] = 'Die entsprechenden ausgewählten';
$lang['Ignore selected anomalies'] = 'Ignorieren Sie gewählte Anomalien';
$lang['Refresh'] = 'Aktualisieren';
$lang['The anomaly will be ignored until next application version'] = 'Der Fehler wird ignoriert bis die nächste Version der Anwendung';
$lang['Correction the anomaly will cancel the fact that it\'s ignored'] = 'Die Korrektur der Anomalie macht die Tatsache sie ignoriert ist';
$lang['%d anomaly has been ignored.'] = '%d Anomalie ignoriert wurde.';
$lang['%d anomalies have been ignored.'] = '%d Anomalien ignoriert wurden.';
$lang['Plugins which need upgrade'] = 'Für diese Plugins ist ein Update verfügbar';
$lang['Plugin list'] = 'Liste der Plugins';
$lang['Check for updates'] = 'Auf Updates überprüfen';
$lang['Other plugins'] = 'Weitere Plugins';
$lang['Last revisions'] = 'Aktuelle änderungen';
$lang['Delete'] = 'Löschen';
$lang['Are you sure you want to delete this plugin?'] = 'Sind Sie sicher dass Sie dieses Plugin löschen möchten?';
$lang['Are you sure you want to install this plugin?'] = 'Sind Sie sicher dass Sie dieses Plugin installieren möchten?';
$lang['Are you sure to install this upgrade? You must verify if this version does not need uninstallation.'] = 'Sind Sie sicher dass Sie dieses Plugin installieren möchten? Stellen sicher, dass die vorhergehende Version nicht deinstalliert werden muss.';
$lang['%s has been successfully upgraded.'] = '%s wurde erfolgreich aktualisiert.';
$lang['Plugin has been successfully copied'] = 'Das Plugin wurde erfolgreich installiert.';
$lang['You might go to plugin list to install and activate it.'] = 'Gehen Sie in die "Liste der Plugins" um installierte Plugins zu aktivieren.';
$lang['Can\'t create temporary file.'] = 'Temporäre Datei kann nicht erstellt .';
$lang['Can\'t download archive.'] = 'Kann Archiv nicht downloaden.';
$lang['Can\'t read or extract archive.'] = 'Kann das Archiv nicht lesen oder entpacken.';
$lang['An error occured during extraction (%s).'] = 'Fehler beim entpacken des Archives(%s).';
$lang['Please check "plugins" folder and sub-folders permissions (CHMOD).'] = 'Überprüfen Sie die Berechtigungen des Ordners "Plugins" und dessen Unterordner (CHMOD).';
$lang['Can\'t connect to server.'] = 'Es konnte keine Verbindung zum Server hergestellt werden.';
$lang['Purge compiled templates'] = 'Löschen der kompilierten Templates';
$lang['ACCESS_0'] = 'Frei';
$lang['ACCESS_1'] = 'Alle';
$lang['ACCESS_2'] = 'Mitglieder';
$lang['ACCESS_3'] = 'Administratoren';
$lang['ACCESS_4'] = 'Webmaster';
$lang['ACCESS_5'] = 'Keine Benutzer';
$lang['Support'] = 'Support';
$lang['Documentation'] = 'WIKI / Dokumentation';
$lang['A new version of Piwigo is available.'] = 'Es steht eine neue Version von Piwigo zur Verfügung.';
$lang['Piwigo Administration'] = 'Verwaltung von Piwigo';
$lang['Piwigo version'] = 'Version von Piwigo';
$lang['You are running the latest version of Piwigo.'] = 'Sie verwenden die neueste Version von Piwigo.';
$lang['The version of %s [%s] installed is not compatible with the version required [%s]'] = 'Die Version %s [%s] ist installiert und ist nicht mit der erforderlichen Version kompatibel [%s]';
$lang['You need to upgrade your system to take full advantage of the application else the application will not work correctly, or not at all'] = 'Sie müssen Ihr System zu aktualisieren, um vollen Nutzen aus der Anwendung nicht die Anwendung funktioniert nicht richtig oder gar nicht';
$lang['Deleted on'] = 'Gelöscht am';
$lang['Last hit'] =  'Letzter Zugriff';
$lang['GD library is missing'] = 'die GD-Library ist nicht auf dem Server installiert, bitte frage den Administrator oder Provider.';
$lang['Templates'] = 'Templates (Modelle)';
$lang['Extend for templates'] = 'Vorlagenerweiterung';
$lang['Replacement of original templates by customized templates from template-extension subfolder'] = 'Ersetzen von Originalvorlagen durch angepasste Vorlagen im Ordner template-extension';

$lang['Replacers (customized templates)'] = 'Replacer (angepasste Vorlagen)';
$lang['Original templates'] = 'Originales Templates';
$lang['Optional URL keyword'] = 'Optionale Parameter in der URL';
$lang['Templates configuration has been recorded.'] = 'Die Konfiguration der Templates gespeichert wurde.';
$lang['All optimizations have been successfully completed.'] = 'Alle Optimierungen wurden erfolgreich abgeschlossen.';
$lang['Optimizations have been completed with some errors.'] = 'Einige Optimierungen endeten mit Fehlern.';
$lang['Modify information'] = 'Informationen ändern';
$lang['edit album'] = 'Die Albuminformation bearbeiten';
$lang['nothing'] = 'nichts';
$lang['overrides existing values with empty ones'] = 'Überschreibt alle existierenden Werte in der Datenbank mit leeren!!  (filesize, width, height, high_filesize, date_creation, keywords, date_creation, author, name, comment)';
$lang['manage photo ranks'] = 'verwalte Foto Rangordnung';
$lang['Manage photo ranks'] = 'Verwalte Foto Rangordnung';
$lang['Edit ranks'] = 'Die Reihenfolge ändern';
$lang['No photo in this album'] = 'Keine Fotos in diesem Album';
$lang['Images manual order was saved'] = 'Die manuelle Reihenfolge der Bilder wurde gespeichert';
$lang['ranks'] = 'Reihenfolge';
$lang['Drag to re-order'] = 'Klicken und Ziehen um eine neue Reihenfolge festzulegen';
$lang['Quick Local Synchronization'] = 'Schnelle Synchronisierung';
$lang['No photo can be deleted'] = 'Kein Foto kann gelöscht werden';
$lang['Delete selected photos'] = 'Lösche ausgewählte Fotos';
$lang['%d photo was deleted'] = '%d Foto wurde gelöscht';
$lang['%d photos were deleted'] = '%d Fotos wurden gelöscht';
$lang['Downloads'] = 'Downloads';
$lang['Released on'] = 'Veröffentlicht am';
$lang['Number of downloads'] = 'Anzahl der Downloads';


// --------- Starting below: New or revised $lang ---- from Colibri
$lang['Piwigo Announcements Newsletter'] = 'Piwigo Newsletter';
$lang['Keep in touch with Piwigo project, subscribe to Piwigo Announcement Newsletter. You will receive emails when a new release is available (sometimes including a security bug fix, it\'s important to know and upgrade) and when major events happen to the project. Only a few emails a year.'] = 'Abonniere den Piwigo Newsletter. Du bekommst eine E-Mail wenn eine neue Version verfügbar ist (manchmal wird ein Bug gefixt, der die Sicherheit der Piwigo erhöht, es ist dann wichtig das Upgrade zu installieren) und wenn es wichtige Ereignisse rund um das Projekt gibt. Es sind nur ein paar E-Mails im Jahr.';
$lang['Subscribe %s'] = 'Abonnieren %s';
$lang['Subscribe %s to Piwigo Announcements Newsletter'] = 'Abonniere %s zum Piwigo Newsletter';
$lang['Purge search history'] = 'Lösche die Such-Historie';
$lang['Hide'] = 'Verstecken';
$lang['Operation in progress'] = 'Arbeite daran.';
$lang['Please wait...'] = 'Bitte warten...';
$lang['Password is missing. Please enter the password.'] = 'Das Kennwort fehlt. Bitte geben sie ihr Kennwort ein.';
$lang['Password confirmation is missing. Please confirm the chosen password.'] = 'Das Kennwort zum überprüfen fehlt. Bitte geben Sie ihr gewähltes Kennwort noch einmal ein.';
$lang['Password confirmation error.'] = 'Fehler bei der Überprüfung des Kennwortes.';
$lang['Allow users to edit their own comments'] = 'Erlaube Benutzern ihre eigenen Kommentare zu editieren';
$lang['Allow users to delete their own comments'] = 'Erlaube Benutzern ihre eigenen Kommentare zu löschen';
$lang['Email administrators when a comment is modified'] = 'Schicke den Administratoren eine E-mail wenn ein Kommentar verändert wurde';
$lang['Email administrators when a comment is deleted'] = 'Schicke den Administratoren eine E-mail wenn ein Kommentar gelöscht wurde';
$lang['Cannot delete the old permalink !'] = 'Kann den alten Permalink nicht löschen !';
$lang['Hit'] = 'Treffer';
$lang['Tools'] = 'Werkzeuge';
$lang['Photos'] = 'Fotos';
$lang['Themes'] = 'Themen';
$lang['Instructions to use Piwigo'] = 'Instruktionen um die Piwigo zu benutzen';
$lang['Installed Themes'] = 'Installierte Themen';
$lang['Add New Theme'] = 'Füge ein neues Thema hinzu';
$lang['Forbid this theme to users'] = 'Verbieten Sie dieses Thema den Benutzern';
$lang['Set as default theme for unregistered and new users'] = 'Setze als Standardthema für unregistrierte und neue Benutzer';
$lang['unknown'] = 'unbekannt';
$lang['Upload Photos'] = 'Lade Fotos hoch';
$lang['Drop into album'] = 'In das Album hochladen';
$lang['+ Add an upload box'] = '+ eine weitere Uploadbox';
$lang['Create the "%s" directory at the root of your Piwigo installation'] = 'Erstelle den  "%s" Ordner im Hauptordner (root) deiner Piwigoinstallation';
$lang['Give write access (chmod 777) to "%s" directory at the root of your Piwigo installation'] = 'Gebe Schreibrechte (chmod 777) dem Ordner "%s" im Hauptordner (root) deiner Piwigoinstallation';
$lang['existing album'] = 'Existierendes Album';
$lang['create a new album'] = 'Ein neues Album erstellen';
$lang['Album name'] = 'Albumname';
$lang['Album "%s" has been added'] = 'Album "%s" wurde hinzugefügt';
$lang['Uploaded Photos'] = 'Lade Fotos hoch';
$lang['%d photos uploaded'] = '%d Fotos hochgeladen';
$lang['Privacy level set to "%s"'] = 'Datenschutzstufe auf "%s" gesetzt';
$lang['Album "%s" now contains %d photos'] = 'Das Album "%s" enthält nun %d Fotos';
$lang['Manage this set of %d photos'] = 'Verwalte dieses Set von %d Fotos';
$lang['Select files'] = 'Wähle Dateien aus';
$lang['Everybody'] = 'Jedermann';
$lang['Who can see these photos?'] = 'Wer soll die Fotos sehen können?';
$lang['Who can see this photo?'] = 'Wer soll dieses Foto sehen können?';
$lang['The websize maximum width must be a number between %d and %d'] = 'Die maximale Breite muss eine Zahl zwischen %d und %d sein';
$lang['The websize maximum height must be a number between %d and %d'] = 'Die maximale Höhe muss eine Zahl zwischen %d und %d sein';
$lang['The websize image quality must be a number between %d and %d'] = 'Die Bildqualität muss eine Zahl zwischen %d und %d sein';
$lang['The thumbnail maximum width must be a number between %d and %d'] = 'Die maximale Breite der Vorschaubilder muss eine Zahl zwischen %d und %d sein';
$lang['The thumbnail maximum height must be a number between %d and %d'] = 'Die maximale Höhe der Vorschaubilder muss eine Zahl zwischen %d und %d sein';
$lang['The thumbnail image quality must be a number between %d and %d'] = 'Die Bildqualität der Vorschaubilder muss eine Zahl zwischen %d und %d sein';
$lang['Settings'] = 'Einstellungen';
$lang['Web size photo'] = 'Größe des angezeigten Bildes';
$lang['Resize'] = 'Größe verändern';
$lang['Maximum Width'] = 'Maximale Breite';
$lang['pixels'] = 'Pixel';
$lang['Maximum Height'] = 'Maximale  Höhe';
$lang['Image Quality'] = 'Bildqualität';
$lang['Save Settings'] = 'Speichere Einstellungen';
$lang['Your configuration settings are saved'] = 'Die Konfigurationseinstellungen wurden gespeichert';
$lang['Active Themes'] = 'Aktive Themen';
$lang['Add write access to the "%s" directory'] = 'Gebe dem Ordner "%s" Schreibrechte';
$lang['Administration Home'] = 'Startseite der Administration';
$lang['Change Admin Colors'] = 'Ändere die Administrationsfarben ';
$lang['Delete this theme'] = 'Lösche dieses Thema';
$lang['Directory does not exist'] = 'Ordner existiert nicht';
$lang['Download,'] = 'Download,';
$lang['FTP + Synchronization'] = 'FTP + Synchronisieren';
$lang['Get Support on Piwigo Forum'] = 'Bekomme Hilfe im Piwigo Forum';
$lang['Help Me'] = 'Hilf mir';
$lang['Impossible to activate this theme, the parent theme is missing: %s'] = 'Es ist nicht möglich dieses Thema zu aktivieren da das Elternthema %s fehlt';
$lang['Impossible to delete this theme. Other themes depends on it: %s'] = 'Es ist nicht möglich dieses Thema zu löschen. Andere Themen basieren darauf: %s';
$lang['Inactive Themes'] = 'Inaktive Themen';
$lang['Install on your computer,'] = 'Installiere auf deinem Computer,';
$lang['Make this theme available to users'] = 'Stelle dieses Thema den Benutzern zur Verfügung';
$lang['Page end'] = 'Ende der Seite';
$lang['Piwigo Uploader'] = 'Piwigo Uploader';
$lang['Read Piwigo Documentation'] = 'Lese die Piwigo Dokumentation';
$lang['Start pLoader and add your photos.'] = 'Starte pLoader und füge deine Fotos hinzu.';
$lang['Switch to clear or dark colors for administration'] = 'Wechsle zwischen hellen und dunklen Farben für die Administration';
$lang['Theme has been successfully installed'] = 'Thema wurde erfolgreich installiert';
$lang['Visit Gallery'] = 'Besuche die Galerie';
$lang['Visit Piwigo project website'] = 'Besuche die Piwigo Projekthomepage';
$lang['pLoader stands for <em>Piwigo Uploader</em>. From your computer, pLoader prepares your photos and transfer them to your Piwigo photo gallery.'] = 'pLoader bedeutet <em>Piwigo Uploader</em>. Auf deinem Computer bereitet der pLoader die Fotos vor und transferiert sie in die Piwigo Fotogalerie.';
$lang['Guest Settings'] = 'Einstellungen für Gäste';
$lang['Main Page'] = 'Hauptseite';
$lang['Photo Page'] = 'Fotoseite';
$lang['Activate Navigation Bar'] = 'Aktiviere Navigationsleiste';
$lang['Activate Navigation Thumbnails'] = 'Aktiviere Navigationsvorschaubilder';
$lang['Activate icon "%s"'] = 'Aktiviere Icon "%s"';
$lang['Activate field "%s"'] = 'Aktiviere  Bereich "%s"';
$lang['Photo Properties'] = 'Fotoeigenschaften';
$lang['Allow user customization'] = 'Erlaube Anpassungen durch Benutzer';
$lang['Execution time is out, treatment must be continue [Estimated time: %d seconds].'] = 'Zeit für die Ausführung ist abgelaufen, der Prozess muss fortgesetzt werden [Noch benötigte Zeit: %d Sekunden].';
$lang['Languages'] = 'Sprachen';
$lang['Installed Languages'] = 'Installierte Sprachen';
$lang['Add New Language'] = 'Füge eine neue Sprache hinzu';
$lang['Language has been successfully installed'] = 'Sprachdateien wurden erfolgreich installiert';
$lang['Select:'] = 'Auswahl:';
$lang['None'] = 'Nichts';
$lang['Invert'] = 'Umkehren';
$lang['Impossible to deactivate this theme, you need at least one theme.'] = 'Es ist nicht möglich dieses Thema zu deaktivieren, du benötigst mindestens ein Thema.';
$lang['Miscellaneous'] = 'Verschiedenes';
$lang['Virtual Links'] = 'Virtuelle Verbindungen';
$lang['Download'] = 'Herunterladen';
$lang['Webmaster status is required.'] = 'Sie benötigen Webmaster-berechtigung.';
$lang['Bound Theme'] = 'Zugewiesene Vorlage';
$lang['Allow rating'] = 'Bewertung von Fotos erlauben';
$lang['Select at least one comment'] = 'Wählen Sie mindestens ein Kommentar aus';
$lang['Active Plugins'] = 'Aktivierte Plugins';
$lang['Inactive Plugins'] = 'Deaktivierte Plugins';
$lang['Missing Plugins'] = 'Fehlende Plugins';
$lang['Uninstalled Plugins'] = 'Deinstallierte Plugins';
$lang['By %s'] = 'Von %s';
$lang['Visit plugin site'] = 'Besuche die Plugin Website';
$lang['Active Languages'] = 'Aktivierte Sprachen';
$lang['Delete this language'] = 'Lösche diese Sprache';
$lang['Forbid this language to users'] = 'Verbiete Benutzern, diese Sprache auszuwählen';
$lang['Impossible to deactivate this language, first set another language as default.'] = 'Sie müssen zuerst eine neue Standardsprache wählen, bevor Sie diese Sprache deaktivieren.';
$lang['Impossible to deactivate this language, you need at least one language.'] = 'Sie können diese Sprache nicht deaktvieren, da mindestens eine Sprache benötigt wird.';
$lang['Inactive Languages'] = 'Deaktivierte Sprachen';
$lang['Make this language available to users'] = 'Aktiviere diese Sprache für Benutzer';
$lang['Set as default language for unregistered and new users'] = 'Als Standardsprache für neue und unregistrierte User festlegen';
$lang['delete'] = 'Löschen:';
$lang['Add Photos'] = 'Fotos hinzufügen';
$lang['The following tag was deleted'] = 'Folgendes Stichwort wurde gelöscht';
$lang['There is no other language available.'] = 'Es ist keine weitere Sprache verfügbar.';
$lang['There is no other plugin available.'] = 'Es ist kein weiteres Plugin verfügbar.';
$lang['There is no other theme available.'] = 'Es ist kein weiteres Thema verfügbar.';
$lang['Add another set of photos'] = 'Füge eine weitere Fotoserie hinzu';
$lang['By rank'] = 'Nach Rangfolge';
$lang['Manual order'] = 'Manuelle Sortierung';
$lang['Order of menubar items has been updated successfully.'] = 'Die Reihenfolge der Menüelemente wurde erfolgreich angepasst.';
$lang['This theme was not designed to be directly activated'] = 'Dieses Layout kann nicht direkt aktiviert werden';
$lang['Pending Comments'] = 'Freizugebende Kommentare';
$lang['Menu Management'] = 'Menü';
$lang['In your php.ini file, the upload_max_filesize (%sB) is bigger than post_max_size (%sB), you should change this setting'] = 'In Ihrer php.ini Datei ist der upload_max_filesize (%sB) größer als post_max_size (%sB), Sie sollten diese Einstellung ändern';
$lang['Exif extension not available, admin should disable exif use'] = 'Exif Erweiterung nicht verfügbar, der Admin sollte die Exif-Verwendung deaktivieren';
$lang['The uploaded file exceeds the upload_max_filesize directive in php.ini: %sB'] = 'Die hochgeladene Datei überschreitet die upload_max_filesize Einstellung in der php.ini: %sB';
$lang['The uploaded files exceed the post_max_size directive in php.ini: %sB'] = 'Die hochgeladenen Dateien überschreiten die post_max_size Einstellung in php.ini: %sB';
$lang['The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form'] = 'Die hochgeladene Datei überschreitet die MAX_FILE_SIZE Einstellung, die in der HTML-Form angegeben wurde';
$lang['The uploaded file was only partially uploaded'] = 'Die hochgeladene Datei wurde nur teilweise übertragen';
$lang['No file was uploaded'] = 'Keine Datei wurde hochgeladen';
$lang['Missing a temporary folder'] = 'Ein temporärer Ordner wird vermisst';
$lang['Failed to write file to disk'] = 'Es ist nicht möglich die Datei zu schreiben';
$lang['File upload stopped by extension'] = 'Das Hochladen der Datei wurde infolgedessen gestoppt';
$lang['Unknown upload error'] = 'Unbekannter Fehler beim hochladen';
$lang['Error on file "%s" : %s'] = 'Fehler bei Datei "%s" : %s';
$lang['automatic order'] = 'automatische Sortierung';
$lang['manual order'] = 'manuelle Sortierung';
$lang['Albums automatically sorted'] = 'Alben automatisch sortiert';
$lang['Keep high definition'] = 'Belasse High Definition';
$lang['The high definition maximum width must be a number between %d and %d'] = 'Die maximale Höhe der High Definition Auflösung muss eine Zahl zwischen %d und %d sein';
$lang['The high definition maximum height must be a number between %d and %d'] = 'Die maximale Breite der High Definition Auflösung muss eine Zahl zwischen %d und %d sein';
$lang['The high definition image quality must be a number between %d and %d'] = 'Die High Definition Bildqualität muss eine Zahl zwischen %d und %d sein';
$lang['Batch Manager'] = 'Stapelverarbeitungsmanager';
$lang['include child albums'] = 'inclusive Unteralben';
$lang['Selection'] = 'Auswahl';
$lang['Action'] = 'Aktion';
$lang['Set author'] = 'Setze den Autor';
$lang['Set title'] = 'Setze den Titel';
$lang['Set creation date'] = 'Setze das Erstellungsdatum';
$lang['Apply action'] = 'Bestätige die Aktion';
$lang['on the %d selected photos'] = 'der %d ausgewählten Fotos';
$lang['%d of %d photos selected'] = '%d von %d Fotos ausgewählt';
$lang['No photo selected, %d photos in current set'] = 'Kein Foto ausgewählt, %d Fotos im gegenwärtigen Set';
$lang['All %d photos are selected'] = 'Alle %d Fotos ausgewählt';
$lang['remove this filter'] = 'entferne diesen Filter';
$lang['predefined filter'] = 'vordefinierter Filter';
$lang['last import'] = 'letzter Import';
$lang['with no virtual album'] = 'ohne virtuelles Album';
$lang['duplicates'] = 'doppelte';
$lang['Add a filter'] = 'Füge einen Filter hinzu';
$lang['Remove all filters'] = 'Entferne alle Filter';
$lang['Refresh photo set'] = 'Aktualisiere das Fotoset';
$lang['The whole page'] = 'Die ganze Seite';
$lang['The whole set'] = 'Das ganze Set';
$lang['No photo in the current set.'] = 'Keine Fotos im gegenwärtigen Set.';
$lang['No photo selected, no action possible.'] = 'Kein Foto ausgewählt, keine Aktion möglich.';
$lang['Choose an action'] = 'Wähle eine Aktion';
$lang['remove author'] = 'entferne den Autor';
$lang['Type here the author name'] = 'Geben Sie hier den Name des Autors ein';
$lang['remove title'] = 'Entferne Titel';
$lang['Type here the title'] = 'Geben Sie hier den Titel ein';
$lang['remove creation date'] = 'Entferne das Erstellungsdatum';
$lang['with no album'] = 'ohne Album';
$lang['with no tag'] = 'ohne Stichwort';
$lang['Album photos associated to the following albums: %s'] = 'Albumfotos findet man in folgenden Alben: %s';
$lang['Delete orphan tags'] = 'Lösche nichtbenutzte Stichworte';
$lang['delete photo'] = 'lösche Foto';
$lang['Orphan tags deleted'] = 'Nichtbenutzte Stichworte wurden gelöscht';
$lang['Week starts on'] = 'Die Woche beginnt mit';
$lang['You have %d orphan tags: %s.'] = 'Sie haben %d nichtbenutzte Stichworte: %s.';
$lang['Remove from caddie'] = 'Vom Sammelkorb entfernen';
$lang['Themes which need upgrade'] = 'Themen, welche einen update brauchen';
$lang['Languages which need upgrade'] = 'Sprachen, welche einen update brauchen';
$lang['All themes are up to date.'] = 'Alle Themen sind auf dem neuesten Stand.';
$lang['All plugins are up to date.'] = 'Alle Plug-Ins sind auf dem neuesten Stand.';
$lang['All languages are up to date.'] = 'Alle Sprachen sind auf dem neuesten Stand.';
$lang['Visit theme site'] = 'Die Themenseite besuchen';
$lang['Visit language site'] = 'Die Sprachenseite besuchen';
$lang['New Version'] = 'Neue Version';
$lang['display'] = 'Zeige';
$lang['Obsolete Plugins'] = 'Veraltete Plugins'; 
$lang['WARNING! This plugin does not seem to be compatible with this version of Piwigo.'] = 'WARNUNG! Dieses Plugin ist nicht kompatibel mit dieser Version der Piwigo.';
$lang['Do you want to activate anyway?'] = 'Wollen Sie es wirklich wieder aktivieren?';
$lang['THIS PLUGIN IS NOW PART OF PIWIGO CORE! DELETE IT NOW.'] = 'DIESES PLUGIN IST JETZT IN DEN KERN DER PIWIGO INTEGRIERT! BITTE UNBEDINGT DEINSTALLIEREN!';
$lang['ERROR: THIS PLUGIN IS MISSING BUT IT IS INSTALLED! UNINSTALL IT NOW.'] = 'ERROR: DIESES PLUGIN FEHLT OBWOHL ES INSTALLIERT IST! BITTE UNBEDINGT DEINSTALLIEREN! ';
$lang['Regenerate Thumbnails'] = 'Vorschaubilder neu erstellen';
$lang['Thumbnails generation in progress...'] = 'Vorschaubilder werden neu erstellt...';
$lang['%s thumbnails have been regenerated'] = '%s Vorschaubilder wurden neu erstellt';
$lang['%s thumbnails can not be regenerated'] = '%s Vorschaubilder konnten nicht neu erstellt werden';
$lang['Regenerate Websize Photos'] = 'Neuerstellung web-optimierter Fotos';
$lang['Photos generation in progress...'] = 'Fotos werden neu erstellt...';
$lang['%s photos have been regenerated'] = '%s Fotos wurden neu erstellt';
$lang['%s photos can not be regenerated'] = '%s Fotos konnten nicht neu erstellt werden';
$lang['new'] = 'neu';
$lang['No results'] = 'Keine Ergebnisse';
$lang['Searching...'] = 'Suche...';
$lang['Type in a search term'] = 'Geben Sie bitte einen Suchbegriff ein';
$lang['Activate icon "new" next to albums and pictures'] = ' Aktivieren Sie das Icon "Neu" neben Alben und Fotos ';
$lang['Deactivate all'] = 'Deaktiviere alle';
$lang['Default photos order'] = 'Voreingestellte Fotoanordnung';
$lang['Restore'] = 'Zurücksetzen';
$lang['Restore default configuration. You will lose your plugin settings!'] = 'Zurücksetzen auf Standardkonfiguration. Alle Einstellungen in diesem Plugin gehen verloren!';
$lang['Show menubar'] = 'Zeige die Menübar';
$lang['Updates'] = 'Aktualisierungen';
$lang['Update in progress... Please wait.'] = 'Aktualisierung in Arbeit…Bitte warten.';
$lang['Ignore this update'] = 'Ignoriere diese Aktualisierung';
$lang['Reset ignored updates'] = 'Zurücksetzen der ignorierten Aktualisierungen';
$lang['Update All'] = 'Aktualisiere alles';
$lang['ERROR'] = 'FEHLER';
$lang['Update Complete'] = 'Aktualisierung komplett';
$lang['Piwigo Update'] = 'Piwigo Aktualisierung';
$lang['Extensions Update'] = 'Aktualisierung der Erweiterungen';
$lang['All extensions are up to date.'] = 'Alle Erweiterungen sind aktuell.';
$lang['Following plugins may not be compatible with the new version of Piwigo:'] = 'Folgende Erweiterungen sind möglicherweise nicht kompatibel mit der neuen Version der Piwigo:';
$lang['Following themes may not be compatible with the new version of Piwigo:'] = ' Folgende Themen sind möglicherweise nicht kompatibel mit der neuen Version der Piwigo:';
$lang['I decide to update anyway'] = 'Ich möchte trotzdem aktualisieren';
$lang['Update to Piwigo %s'] = 'Aktualisierung auf Piwigo %s';
$lang['Two updates are available'] = 'Zwei Aktualisierungen sind verfügbar';
$lang['This is a minor update, with only bug corrections.'] = 'Dies ist eine kleine Aktualisierung nur zur Fehlerbeseitigung.';
$lang['This is a major update, with <a href="%s">new exciting features</a>.'] = 'Dies ist eine größere Aktualisierung  mit <a href="%s">neuen Funktionen </a>.';
$lang['Some themes and plugins may be not available yet.'] = 'Einigen Themen und Erweiterungen sind nun leider nicht mehr verfügbar.';
$lang['You can update to Piwigo %s directly, without upgrading to Piwigo %s (recommended).'] = 'Sie können direkt auf Piwigo %s aktualisieren ohne vorher auf Piwigo %s zu aktualisieren (empfohlen).';
$lang['Save Template Directory'] = 'Sichere den Template-Ordner';
$lang['Dump Database'] = 'Sichere die Datenbank';
$lang['Include history data (Warning: server memory limit may be exceeded)'] = 'Sichere auch die Daten der History (Warnung: kann das Speicherlimit des Servers überschreiten)';
$lang['Unable to write new local directory.'] = 'Es ist nicht möglich einen neuen lokalen Ordner zu erstellen.';
$lang['Unable to send template directory.'] = 'Es ist nicht möglich den Templateordner zu senden.';
$lang['Unable to dump database.'] = 'Es ist nicht möglich die Datenbank zu sichern.';
$lang['Some upgrades are available for extensions.'] = 'Einige Aktualisierungen für Erweiterungen sind verfügbar.';
$lang['Ignore All'] = 'Ignoriere alle';
$lang['Crop'] = 'Zuschneiden';
$lang['Width'] = 'Breite';
$lang['Height'] = 'Höhe';
$lang['Follow Orientation'] = 'Folgen Sie der Orientierung';
$lang['If you want to regenerate thumbnails, please go to the <a href="%s">Batch Manager</a>.'] = 'Wenn Sie die Vorschaubilder erneuern möchten gehen Sie bitte zum <a href="%s"> Stapelverarbeitungsmanager</a>.';
$lang['Graphics Library'] = ' Grafikbibliothek';
$lang['Add a criteria'] = 'Ein Kriterium hinzufügen'; 
$lang['You can\'t define a default photo order because you have a custom setting in your local configuration.'] = ' Sie können keine Standardsortierung festlegen da Sie eine benutzerdefinierte Einstellung in Ihrer lokalen Konfiguration festgelegt haben.';
$lang['You have specified <i>$conf[\'order_by\']</i> in your local configuration file, this parameter in deprecated, please remove it or rename it into <i>$conf[\'order_by_custom\']</i> !'] = 'Sie haben <i>$conf[\'order_by\']</i> in ihrer lokalen Konfigurationsdatei festgelegt, dieser Parameter wird abgelehnt, bitte entfernen sie ihn oder benennen sie ihn um in <i>$conf[\'order_by_custom\']</i> !';
$lang['Average rate'] = 'Durchschnittliche Bewertung';
$lang['Rate'] = 'Bewertung';
$lang['Learn more'] = 'Mehr Informationen';
$lang['An error has occured during upgrade.'] = 'Ein Fehler trat während des Aktualisierens auf.';
$lang['An error has occured during extract. Please check files permissions of your piwigo installation.<br><a href="%s">Click here to show log error</a>.'] = 'Ein Fehler trat während des Entpackens auf. Bitte prüfen Sie die Schreibrechte ihrer Piwigo Installation.<br><a href="%s">Klicken Sie hier für das Fehlerprotokoll</a>.';
$lang['Piwigo cannot retrieve upgrade file from server'] = 'Piwigo kann die Aktualisierungsdatei nicht vom Server laden';
$lang['(this tag will be deleted)'] = '(dieser Tag wird gelöscht!)';
$lang['... or '] = '... oder';
$lang['Allowed file types: %s.'] = 'Erlaubte Dateitypen: %s.';
$lang['By default, Piwigo will create a new websize from the HD (high definition) version of your photo.'] = 'Standardmäßig erstellt Piwigo eine für Web optimierete Ansicht der HD-Version (hochaufgelösten Version) deines Fotos';
$lang['Confirm merge'] = 'Zusammenführen bestätigen';
$lang['Create'] = 'Erstellen';
$lang['hide details'] = 'Details verbergen';
$lang['If no HD is available and if the current websize is bigger than resize dimensions, Piwigo will move it as HD and create a downsized websize photo from it.'] = 'Wenn das Bild nicht HD (hochaufgelöst) ist und das Bild kleiner ist als die für Web optimierte Größe, verwendet Piwigo dieses als HD und erstellt eine verkleinerte Web optimierten Version';
$lang['Manage Permissions'] = 'Zugriff verwalten';
$lang['Maximum file size: %sB.'] = 'Max. Dateigröße: %sB.';
$lang['Merge selected tags'] = 'Gewählte Tags zusammenführen';
$lang['Merge tags'] = 'Tags zusammenführen';
$lang['No destination tag selected'] = 'Keinen Ziel-Tag gewählt';
$lang['Photo %s of %s'] = 'Bild %s of %s';
$lang['Select an album'] = 'Wähle ein Album';
$lang['Select at least two tags for merging'] = 'Wahle 2 Tags zum Zusammenführen';
$lang['Select the destination tag'] = 'Wähle Ziel-Tag';
$lang['show details'] = 'Details zeigen';
$lang['Start Upload'] = 'Upload starten';
$lang['Tags <em>%s</em> merged into tag <em>%s</em>'] = 'Tags <em>%s</em> in <em>%s</em> zusammengeführt';
$lang['You are using the Browser uploader. Try the <a href="%s">Flash uploader</a> instead.'] = 'Du benutzt den einfachen Uploader. Benutze den <a href="%s">Flash uploader</a> stattdessen.';
$lang['You are using the Flash uploader. Problems? Try the <a href="%s">Browser uploader</a> instead.'] = 'Probleme mit dem Flash Uploader. Benutze den <a href="%s">Browser uploader</a>';
?>